@@ -521,8 +521,11 @@ class DataStore(Mapping):
     def __iter__(self):
         return iter(self.data)
 
+    def pop(self, key):
+        return self.data.pop(key, None)
+
     def __delitem__(self, key):
-        del self.data[key]
+        self.data.pop(key, None)
 
     @property
     def mutable(self):
@@ -703,3 +706,9 @@ def _fast_crc(count=25):
 # get the fastest CRC32 available on the
 # current platform when trimesh is imported
 crc32 = _fast_crc()
+
+# add a shortcut for fast hashing
+if xxhash is None:
+    fast_hash = crc32
+else:
+    def fast_hash(x): return xxhash.xxh64(x).intdigest()
