@@ -55,6 +55,9 @@ class TransformForest(object):
           Distance to translate
         geometry : hashable
           Geometry object name, e.g. 'mesh_0'
+        extras: dictionary
+          Optional metadata attached to the new frame
+          (expors to glTF node 'extras').
         """
 
         self._updated = str(np.random.random())
@@ -72,6 +75,9 @@ class TransformForest(object):
         if 'geometry' in kwargs:
             attr['geometry'] = kwargs['geometry']
 
+        if 'extras' in kwargs:
+            attr['extras'] = kwargs['extras']
+
         # add the edges
         changed = self.transforms.add_edge(frame_from,
                                            frame_to,
@@ -82,6 +88,7 @@ class TransformForest(object):
                 self.transforms,
                 name='geometry',
                 values={frame_to: kwargs['geometry']})
+
         # if the edge update changed our structure
         # dump our cache of shortest paths
         if changed:
@@ -123,21 +130,29 @@ class TransformForest(object):
             }
         return flat
 
-    def to_gltf(self, scene):
+    def to_gltf(self, scene, mesh_index=None):
         """
         Export a transforms as the 'nodes' section of a GLTF dict.
         Flattens tree.
 
+        Parameters
+        ------------
+        scene : trimesh.Scene
+          Scene with geoemtry
+        mesh_index : dict or None
+          Mapping { key in scene.geometry : int }
+
         Returns
         --------
         gltf : dict
           with 'nodes' referencing a list of dicts
         """
 
-        # geometry is an OrderedDict
-        # map mesh name to index: {geometry key : index}
-        mesh_index = {name: i for i, name
-                      in enumerate(scene.geometry.keys())}
+        if mesh_index is None:
+            # geometry is an OrderedDict
+            # map mesh name to index: {geometry key : index}
+            mesh_index = {name: i for i, name
+                          in enumerate(scene.geometry.keys())}
 
         # shortcut to graph
         graph = self.transforms
@@ -157,20 +172,31 @@ class TransformForest(object):
             lookup[node] = len(result)
             result.append({'name': node})
 
+        # does the scene have a defined camera to export
+        has_camera = scene.has_camera
+
         # then iterate through to collect data
         for info in result:
             # name of the scene node
             node = info['name']
             # store children as indexes
-            children = [lookup[k] for k in graph[node].keys()]
+
+            try:
+                children = [lookup[k] for k in graph[node].keys() if k in lookup]
+            except KeyError:
+                continue
+
             if len(children) > 0:
                 info['children'] = children
             # if we have a mesh store by index
             if 'geometry' in node_data[node]:
-                info['mesh'] = mesh_index[node_data[node]['geometry']]
+                mesh_key = node_data[node]['geometry']
+                if mesh_key in mesh_index:
+                    info['mesh'] = mesh_index[mesh_key]
             # check to see if we have camera node
-            if node == scene.camera.name:
+            if has_camera and node == scene.camera.name:
                 info['camera'] = 0
+
             try:
                 # try to ignore KeyError and StopIteration
                 # parent-child transform is stored in child
@@ -182,6 +208,14 @@ class TransformForest(object):
                     info['matrix'] = matrix.T.reshape(-1).tolist()
             except BaseException:
                 continue
+
+            try:
+                extras = graph.get_edge_data(parent, node)['extras']
+                if extras:
+                    info['extras'] = extras
+            except BaseException:
+                pass
+
         return {'nodes': result}
 
     def to_edgelist(self):
